@@ -247,13 +247,15 @@ sub _draw_with {
     my @commands = ($plotter);
     return $self->run_with(
         do => \@commands,
-        writer => $args{writer},
-        async => $args{async},
-        output => $args{output},
-        no_stderr => $args{no_stderr}
+        _pair_slice(\%args, qw(writer async output no_stderr))
     );
 }
 
+sub _pair_slice {
+    my ($hash_ref, @keys) = @_;
+    return map { exists($hash_ref->{$_}) ? ($_ => $hash_ref->{$_}) : () } @keys;
+}
+
 sub plot_with {
     my ($self, %args) = @_;
     return $self->_draw_with(%args, command => "plot");
@@ -294,10 +296,7 @@ sub multiplot_with {
     my @commands = ($multiplot_command, $wrapped_do, "unset multiplot");
     return $self->run_with(
         do => \@commands,
-        writer => $args{writer},
-        async => $args{async},
-        output => $args{output},
-        no_stderr => $args{no_stderr}
+        _pair_slice(\%args, qw(writer async output no_stderr))
     );
 }
 
@@ -322,7 +321,7 @@ sub run_with {
     }elsif(ref($commands) ne "ARRAY") {
         $commands = [$commands];
     }
-    _wrap_commands_with_output($commands, $args{output});
+    _wrap_commands_with_output($commands, $self->_plotting_option(\%args, "output"));
     my $do = sub {
         my $writer = shift;
         (!defined($_context_writer) || refaddr($_context_writer) != refaddr($writer))
@@ -341,21 +340,68 @@ sub run_with {
     };
 
     my $result = "";
-    if(defined($args{writer})) {
-        $do->($args{writer});
+    my $got_writer = $self->_plotting_option(\%args, "writer");
+    if(defined($got_writer)) {
+        $do->($got_writer);
     }elsif(defined($_context_writer)) {
         $do->($_context_writer);
     }else {
-        $result = Gnuplot::Builder::Process->with_new_process(async => $args{async}, do => $do, no_stderr => $args{no_stderr});
+        $result = Gnuplot::Builder::Process->with_new_process(
+            async => $self->_plotting_option(\%args, "async"),
+            do => $do,
+            no_stderr => $self->_plotting_option(\%args, "no_stderr")
+        );
     }
     return $result;
 }
 
+sub _plotting_option {
+    my ($self, $given_args_ref, $key) = @_;
+    return (exists $given_args_ref->{$key})
+        ? $given_args_ref->{$key}
+        : $self->get_plot($key);
+}
+
 sub run {
     my ($self, @commands) = @_;
     return $self->run_with(do => \@commands);
 }
 
+my %KNOWN_PLOTTING_OPTIONS = map { ($_ => 1) } qw(output no_stderr writer async);
+
+sub _check_plotting_option {
+    my ($arg_name) = @_;
+    croak "Unknown plotting option: $arg_name" if !$KNOWN_PLOTTING_OPTIONS{$arg_name};
+}
+
+sub set_plot {
+    my ($self, %opts) = @_;
+    foreach my $key (keys %opts) {
+        _check_plotting_option($key);
+        $self->{pdata}->set_attribute(
+            key => $key,
+            value => $opts{$key}
+        );
+    }
+    return $self;
+}
+
+sub get_plot {
+    my ($self, $arg_name) = @_;
+    _check_plotting_option($arg_name);
+    croak "arg_name cannot be undef" if not defined $arg_name;
+    return $self->{pdata}->get_resolved_attribute($arg_name);
+}
+
+sub delete_plot {
+    my ($self, @arg_names) = @_;
+    foreach my $arg_name (@arg_names) {
+        _check_plotting_option($arg_name);
+        $self->{pdata}->delete_attribute($arg_name) 
+    }
+    return $self;
+}
+
 1;
 
 __END__
@@ -832,7 +878,9 @@ the C<plot()> method doesn't generate the inline data section.
 
 Plot with more functionalities than C<plot()> method.
 
-Fields in C<%args> are
+Fields in C<%args> are as follows.
+Note that you can store default values for some arguments in C<$builder>.
+See L<"OBJECT METHODS - PLOTTING OPTIONS"> for detail.
 
 =over
 
@@ -1166,6 +1214,78 @@ See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for deta
     ## => plot 'c.dat' u 1:2 title 'c'
     ## => plot 'd.dat' u 1:2 title 'd'
 
+=head1 OBJECT METHODS - PLOTTING OPTIONS
+
+B<< Methods in this section are currently experimental. >>
+
+As you can see in L<"OBJECT METHODS - PLOTTING">,
+C<plot_with()>, C<splot_with()>, C<multiplot_with()> and C<run_with()> methods
+share some arguments.
+With the methods listed in this section, you can store default values for these arguments in a C<$builder> instance.
+
+You can store default values for the following plotting options:
+
+=over
+
+=item C<output> => OUTPUT_FILENAME
+
+=item C<no_stderr> => BOOL
+
+=item C<writer> => CODE-REF
+
+=item C<async> => BOOL
+
+=back
+
+For detail about these arguments, see L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method.
+
+Note that those default values also affect the behavior of short-hand methods, i.e. C<plot()>, C<splot()>, C<multiplot()> and C<run()>.
+
+The default values stored in a C<$builder> are used when the correponding arguments are not passed to the plotting methods.
+In other words, arguments directly passed to the plotting methods have precedence over the per-instance default values.
+
+The plotting options stored in a C<$builder> is inheritable, just like the "set" and "define" options.
+
+=head2 $builder = $builder->set_plot($arg_name => $arg_value, ...)
+
+Set the plotting option C<$arg_name> to C<$arg_value>.
+C<$arg_name> must be one of the plotting options listed above.
+You can set more than one C<< $arg_name => $arg_value >> pairs.
+
+    $builder->set_plot(
+        output => "hoge.png",
+        async => 1
+    );
+    
+    $builder->plot('sin(x)');
+    ## Same as:
+    ##   $builder->plot_with(
+    ##       dataset => 'sin(x)',
+    ##       output => "hoge.png",
+    ##       async => 1
+    ##   );
+    
+    $builder->plot_with(
+        dataset => 'cos(x)',
+        output => 'foobar.png'
+    );
+    ## Same as:
+    ##   $builder->plot_with(
+    ##       dataset => 'cos(x)',
+    ##       output => 'foobar.png',
+    ##       async => 1
+    ##   );
+
+=head2 $arg_value = $builder->get_plot($arg_name)
+
+Get the value for C<$arg_name>.
+
+If C<$arg_name> is not set in C<$builder>, it returns the value set in its parent builder.
+If none of the ancestors have C<$arg_name>, it returns C<undef>.
+
+=head2 $builder = $builder->delete_plot($arg_name, ...)
+
+Delete the default value for C<$arg_name>. You can specify more than one C<$arg_name>s.
 
 =head1 OBJECT METHODS - INHERITANCE
 
@@ -1195,6 +1315,11 @@ if they are already set in C<$parent>.
 
 =back
 
+A simlar rule is applied to plotting options.
+Plotting options in C<$child> are used if those options are set in C<$child>.
+Otherwise, plotting options in C<$parent> are used.
+
+
 
 =head2 $builder = $builder->set_parent($parent_builder)
 
